"use strict";
const tslib_1 = require("tslib");
const axios_1 = (0, tslib_1.__importDefault)(require("axios"));
const semver_1 = require("semver");
const detect_node_1 = (0, tslib_1.__importDefault)(require("detect-node"));
const maps_1 = require("./api/maps");
const search_1 = require("./api/search");
class BeatSaverAPI {
    constructor(options) {
        this.appName = options.AppName;
        const appVersionSemVer = (0, semver_1.valid)(options.Version);
        if (!appVersionSemVer)
            throw new Error('Invalid App Version. App Version needs to be valid SemVer.');
        this.appVersion = appVersionSemVer;
        this.axiosInstance = axios_1.default.create({
            baseURL: 'https://api.beatsaver.com',
            headers: !detect_node_1.default
                ? {}
                : {
                    'User-Agent': `${this.appName}/${this.appVersion}`,
                },
        });
    }
    getMapByID(id) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return (0, maps_1.getMapByID)(this.axiosInstance, id);
        });
    }
    getMapByHash(hash) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return (0, maps_1.getMapByHash)(this.axiosInstance, hash);
        });
    }
    getMapsByUploader(userID, page = 0) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return (0, maps_1.getMapsByUploader)(this.axiosInstance, userID, page);
        });
    }
    getLatestMaps(automapper, before) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return (0, maps_1.getLatestMaps)(this.axiosInstance, automapper, before);
        });
    }
    searchMaps(searchOptions, page = 0) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return (0, search_1.searchMaps)(this.axiosInstance, searchOptions, page);
        });
    }
}
module.exports = BeatSaverAPI;
